diff --git a/test/decoupled/1p/test_diffusion3d.cc b/test/decoupled/1p/test_diffusion3d.cc
index 69ef727d1d0cbae8e0c29ab0c62ecd3e6bc7c51b..fad45f6d5a0a647f6dda6c905a841d1ef18deaa7 100644
--- a/test/decoupled/1p/test_diffusion3d.cc
+++ b/test/decoupled/1p/test_diffusion3d.cc
@@ -225,12 +225,10 @@ int main(int argc, char** argv)
     return 3;
 }
 #else
-
-#warning You need to have ALUGrid or UG installed to run this test
-
 int main()
 {
-    std::cerr << "You need to have ALUGrid or UG installed to run this test\n";
+#warning You need to have dune-ALUGrid or UG installed to run this test
+    std::cerr << "You need to have dune-ALUGrid or UG installed to run this test\n";
     return 77;
 }
 #endif // HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG
diff --git a/test/decoupled/2p/test_3d2p.cc b/test/decoupled/2p/test_3d2p.cc
index 1c77df7a12d2c0e5c27fbf628bee4f8d3214fa00..1ce5d767b726569d2662fb9deaaec8e4d84b31b9 100644
--- a/test/decoupled/2p/test_3d2p.cc
+++ b/test/decoupled/2p/test_3d2p.cc
@@ -177,14 +177,12 @@ int main(int argc, char** argv)
 
 #else
 
-#warning You need to have ALUGrid installed to run this test
-
 #include <iostream>
 
 int main()
 {
-    std::cerr << "You need to have ALUGrid installed to run this test\n";
+#warning You need to have dune-ALUGrid installed to run this test
+    std::cerr << "You need to have dune-ALUGrid installed to run this test\n";
     return 77;
 }
-
 #endif
diff --git a/test/decoupled/2p/test_impesadaptive.cc b/test/decoupled/2p/test_impesadaptive.cc
index 7de73df93ab390e4bdf9b76f9653efd879f80d3f..993eb575b802f66250d15555b8336cc551e8a0fe 100644
--- a/test/decoupled/2p/test_impesadaptive.cc
+++ b/test/decoupled/2p/test_impesadaptive.cc
@@ -58,13 +58,12 @@ int main(int argc, char** argv)
 }
 #else
 
-#warning You need to have ALUGrid installed to run this test
-
 #include <iostream>
 
 int main()
 {
-    std::cerr << "You need to have ALUGrid installed to run this test\n";
+#warning You need to have dune-ALUGrid installed to run this test
+    std::cerr << "You need to have dune-ALUGrid installed to run this test\n";
     return 77;
 }
 #endif // HAVE_ALUGRID
diff --git a/test/decoupled/2p/test_mpfa2p.cc b/test/decoupled/2p/test_mpfa2p.cc
index 13b05818839a9ec0d849db4105062663ebabed59..0029b8afa18b737e4d93f040696edb53db483eab 100644
--- a/test/decoupled/2p/test_mpfa2p.cc
+++ b/test/decoupled/2p/test_mpfa2p.cc
@@ -151,14 +151,12 @@ int main(int argc, char** argv)
 
 #else
 
-#warning You need to have ALUGrid installed to run this test
-
 #include <iostream>
 
 int main()
 {
-    std::cerr << "You need to have ALUGrid installed to run this test\n";
+#warning You need to have dune-ALUGrid installed to run this test
+    std::cerr << "You need to have dune-ALUGrid installed to run this test\n";
     return 77;
 }
-
 #endif
diff --git a/test/decoupled/2p2c/test_adaptive2p2c2d.cc b/test/decoupled/2p2c/test_adaptive2p2c2d.cc
index ccdc51cabbb969e4a2c28d3b368f11c0dc950f4c..e69f60615a0838efa1b22a888c2202e27aab99fe 100644
--- a/test/decoupled/2p2c/test_adaptive2p2c2d.cc
+++ b/test/decoupled/2p2c/test_adaptive2p2c2d.cc
@@ -60,7 +60,7 @@ int main(int argc, char** argv)
     return Dumux::start<TypeTag>(argc, argv, usage);
 #else
 #warning ALUGrid needed for this test.
-    std::cout << "ALUGrid needed for this test. Aborting." << std::endl;
+    std::cerr << "ALUGrid needed for this test. Aborting." << std::endl;
     return 77;
 #endif
 }
diff --git a/test/decoupled/2p2c/test_adaptive2p2c3d.cc b/test/decoupled/2p2c/test_adaptive2p2c3d.cc
index d372c08ca242a4bcdffb80acd160cc415f1366cc..4c35be3f839b8d425e4ba8673cda8edfc40732b0 100644
--- a/test/decoupled/2p2c/test_adaptive2p2c3d.cc
+++ b/test/decoupled/2p2c/test_adaptive2p2c3d.cc
@@ -63,13 +63,12 @@ int main(int argc, char** argv)
 
 #else
 
-#warning You need to have ALUGrid installed to run this test
-
 #include <iostream>
 
 int main()
 {
-    std::cerr << "You need to have ALUGrid installed to run this test\n";
+#warning You need to have dune-ALUGrid installed to run this test
+    std::cerr << "You need to have dune-ALUGrid installed to run this test\n";
     return 77;
 }
 #endif // HAVE_ALUGRID || HAVE_DUNE_ALUGRID
diff --git a/test/geomechanics/el2p/test_el2p.cc b/test/geomechanics/el2p/test_el2p.cc
index f59c6d8afa9ec3752333f0ffe50f2d9340dec558..ccfa4e1102008888227fd24478cad693d895ce1b 100644
--- a/test/geomechanics/el2p/test_el2p.cc
+++ b/test/geomechanics/el2p/test_el2p.cc
@@ -104,12 +104,11 @@ int main(int argc, char** argv) {
 
 #else // HAVE_DUNE_PDELAB
 
-#warning You need to have dune-pdelab (>= 2.0) installed to run this test.
-
 #include <iostream>
 
 int main()
 {
+#warning You need to have dune-pdelab (>= 2.0) installed to run this test.
     std::cerr << "You need to have dune-pdelab (>= 2.0) installed to run this test.\n";
     return 77;
 }
diff --git a/test/implicit/1p/test_box1p1d3d.cc b/test/implicit/1p/test_box1p1d3d.cc
index 79f3611b1f4b7a899ef1743ad85d107bf0c6eaea..cde671079d0aa02fc1cf505c9e7cbf4fce98085f 100644
--- a/test/implicit/1p/test_box1p1d3d.cc
+++ b/test/implicit/1p/test_box1p1d3d.cc
@@ -63,7 +63,8 @@ int main(int argc, char** argv)
     typedef TTAG(OnePOneDThreeDTestBoxProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-    std::cout << "Test skipped, it needs Alberta!" << std::endl;
+#warning External grid Alberta needed to run this example.
+    std::cerr << "Test skipped, it needs Alberta!" << std::endl;
     return 77;
 #endif
 }
diff --git a/test/implicit/1p/test_box1p2d3d.cc b/test/implicit/1p/test_box1p2d3d.cc
index b66d95cfdf73149e1bfbc1211977cc2575f800cf..bca74640c964276952f7bd0bcf1a1a8f360bb06c 100644
--- a/test/implicit/1p/test_box1p2d3d.cc
+++ b/test/implicit/1p/test_box1p2d3d.cc
@@ -63,7 +63,8 @@ int main(int argc, char** argv)
     typedef TTAG(OnePTwoDThreeDTestBoxProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-    std::cout << "Test skipped, it needs Alberta!" << std::endl;
+#warning External grid Alberta needed to run this example.
+    std::cerr << "Test skipped, it needs Alberta!" << std::endl;
     return 77;
 #endif
 }
diff --git a/test/implicit/1p/test_cc1p1d3d.cc b/test/implicit/1p/test_cc1p1d3d.cc
index 6502e9f9d05fd479094e54e474d2e53bae14b5db..46fed9ad11d2ce20879ab32c84f5dced5368dbe0 100644
--- a/test/implicit/1p/test_cc1p1d3d.cc
+++ b/test/implicit/1p/test_cc1p1d3d.cc
@@ -63,7 +63,8 @@ int main(int argc, char** argv)
     typedef TTAG(OnePOneDThreeDTestCCProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-    std::cout << "Test skipped, it needs Alberta!" << std::endl;
+#warning External grid Alberta needed to run this example.
+    std::cerr << "Test skipped, it needs Alberta!" << std::endl;
     return 77;
 #endif
 }
diff --git a/test/implicit/1p/test_cc1p2d3d.cc b/test/implicit/1p/test_cc1p2d3d.cc
index 9a3725b7e16d9ba1438850b5329af759629c943d..813ec03aff9ea60b997199c1e868a3126137ed1f 100644
--- a/test/implicit/1p/test_cc1p2d3d.cc
+++ b/test/implicit/1p/test_cc1p2d3d.cc
@@ -63,7 +63,8 @@ int main(int argc, char** argv)
     typedef TTAG(OnePTwoDThreeDTestCCProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-    std::cout << "Test skipped, it needs Alberta!" << std::endl;
+#warning External grid Alberta needed to run this example.
+    std::cerr << "Test skipped, it needs Alberta!" << std::endl;
     return 77;
 #endif
 }
diff --git a/test/implicit/2p/test_boxadaptive2p.cc b/test/implicit/2p/test_boxadaptive2p.cc
index 39170d1a3348d3180a9b18f546cb3d6fdc369a07..2fa81283372bb497d4510ef86f317f1e3a0cef71 100644
--- a/test/implicit/2p/test_boxadaptive2p.cc
+++ b/test/implicit/2p/test_boxadaptive2p.cc
@@ -65,6 +65,8 @@ int main(int argc, char** argv)
     typedef TTAG(LensBoxAdaptiveProblem) TypeTag;
     return Dumux::start<TypeTag>(argc, argv, usage);
 #else
+#warning You need dune-ALUGrid to run this test.
+    std::cerr << "You need dune-ALUGrid to run this test." << std::endl;
     return 77;
 #endif
 }
diff --git a/test/implicit/2p/test_ccadaptive2p.cc b/test/implicit/2p/test_ccadaptive2p.cc
index 2a0ffe641c84fef8803dc2f0fd2d0cf6f38a522e..639c50e43e59f8db9f5dc45702e0833294063d5f 100644
--- a/test/implicit/2p/test_ccadaptive2p.cc
+++ b/test/implicit/2p/test_ccadaptive2p.cc
@@ -66,6 +66,8 @@ int main(int argc, char** argv)
     typedef TTAG(LensCCAdaptiveProblem) TypeTag;
     return Dumux::start<TypeTag>(argc, argv, usage);
 #else
+#warning You need dune-ALUGrid to run this test.
+    std::cerr << "You need dune-ALUGrid to run this test." << std::endl;
     return 77;
 #endif
 
diff --git a/test/implicit/2pdfm/test_2pdfm.cc b/test/implicit/2pdfm/test_2pdfm.cc
index bf18b00a41f13f57d1744065e9b8f06b71c0ee69..357c7feebd65d4938b6ff5134b2161f813f4ac53 100644
--- a/test/implicit/2pdfm/test_2pdfm.cc
+++ b/test/implicit/2pdfm/test_2pdfm.cc
@@ -62,11 +62,10 @@ int main(int argc, char** argv)
 }
 
 #else // HAVE_UG
-
 int main(int argc, char** argv)
 {
-    std::cout << "External grid UG needed to run this example." << std::endl;
+#warning External grid UG needed to run this example.
+    std::cerr << "External grid UG needed to run this example." << std::endl;
     return 77;
 }
-
 #endif // HAVE_UG
\ No newline at end of file
diff --git a/test/implicit/co2/test_boxco2.cc b/test/implicit/co2/test_boxco2.cc
index 833b660a6dc21aeddf32fff11235a10e168504ca..b992b93c18941915cb920af7ad99e173e68db909 100644
--- a/test/implicit/co2/test_boxco2.cc
+++ b/test/implicit/co2/test_boxco2.cc
@@ -67,10 +67,12 @@ void usage(const char *progName, const std::string &errorMsg)
 int main(int argc, char** argv)
 {
 #if !DUNE_GRID_EXPERIMENTAL_GRID_EXTENSIONS
-    std::cout << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
+#warning Test needs experimental grid extensions.
+    std::cerr << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
     return 77;
 #elif !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
-    std::cout << "Test skipped, it needs ALUGrid, see optim.opts or debug.opts." << std::endl;
+#warning You need to have dune-ALUGrid installed to run this test.
+    std::cerr << "You need to have dune-ALUGrid installed to run this test." << std::endl;
     return 77;
 #else
     typedef TTAG(HeterogeneousBoxProblem) ProblemTypeTag;
diff --git a/test/implicit/co2/test_boxco2ni.cc b/test/implicit/co2/test_boxco2ni.cc
index df9b4f940fd7f72dc58d25a4848d91fe0f05457b..86004ef0048c06d2f58fd767d7ebd80690984c4b 100644
--- a/test/implicit/co2/test_boxco2ni.cc
+++ b/test/implicit/co2/test_boxco2ni.cc
@@ -68,10 +68,12 @@ void usage(const char *progName, const std::string &errorMsg)
 int main(int argc, char** argv)
 {
 #if !DUNE_GRID_EXPERIMENTAL_GRID_EXTENSIONS
-    std::cout << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
+#warning Test needs experimental grid extensions.
+    std::cerr << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
     return 77;
 #elif !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
-    std::cout << "Test skipped, it needs ALUGrid, see optim.opts or debug.opts." << std::endl;
+#warning You need to have dune-ALUGrid installed to run this test.
+    std::cerr << "You need to have dune-ALUGrid installed to run this test." << std::endl;
     return 77;
 #else
     typedef TTAG(HeterogeneousNIBoxProblem) ProblemTypeTag;
diff --git a/test/implicit/co2/test_ccco2.cc b/test/implicit/co2/test_ccco2.cc
index 92ea99db7df81544074f5114de348a27c04b4bda..b3eacc9a74fc8cce9dcd64e4fb22b3829050955b 100644
--- a/test/implicit/co2/test_ccco2.cc
+++ b/test/implicit/co2/test_ccco2.cc
@@ -67,10 +67,12 @@ void usage(const char *progName, const std::string &errorMsg)
 int main(int argc, char** argv)
 {
 #if !DUNE_GRID_EXPERIMENTAL_GRID_EXTENSIONS
-    std::cout << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
+#warning Test needs experimental grid extensions.
+    std::cerr << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
     return 77;
 #elif !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
-    std::cout << "Test skipped, it needs ALUGrid, see optim.opts or debug.opts." << std::endl;
+#warning You need to have dune-ALUGrid installed to run this test.
+    std::cerr << "You need to have dune-ALUGrid installed to run this test." << std::endl;
     return 77;
 #else
     typedef TTAG(HeterogeneousCCProblem) ProblemTypeTag;
diff --git a/test/implicit/co2/test_ccco2ni.cc b/test/implicit/co2/test_ccco2ni.cc
index d6e50fdba8827ada8894412803eb2144b0755f08..e7e591ab3ad81f4e816e1867d03ee75adc41ebee 100644
--- a/test/implicit/co2/test_ccco2ni.cc
+++ b/test/implicit/co2/test_ccco2ni.cc
@@ -68,10 +68,12 @@ void usage(const char *progName, const std::string &errorMsg)
 int main(int argc, char** argv)
 {
 #if !DUNE_GRID_EXPERIMENTAL_GRID_EXTENSIONS
-    std::cout << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
+#warning Test needs experimental grid extensions.
+    std::cerr << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
     return 77;
 #elif !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
-    std::cout << "Test skipped, it needs ALUGrid, see optim.opts or debug.opts." << std::endl;
+#warning You need to have dune-ALUGrid installed to run this test.
+    std::cerr << "You need to have dune-ALUGrid installed to run this test." << std::endl;
     return 77;
 #else
     typedef TTAG(HeterogeneousNICCProblem) ProblemTypeTag;
diff --git a/test/implicit/mpnc/test_boxmpnckinetic.cc b/test/implicit/mpnc/test_boxmpnckinetic.cc
index 9327bc90ac175d6f2cc332489565a8ba421b52a1..d1dccc42b6ca117e0d722e11abbf5be5e3899aef 100644
--- a/test/implicit/mpnc/test_boxmpnckinetic.cc
+++ b/test/implicit/mpnc/test_boxmpnckinetic.cc
@@ -257,7 +257,8 @@ int start(int argc, char **argv)
 int main(int argc, char** argv)
 {
 #if !HAVE_UG && !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
-    std::cout<<"Evaporation Atmosphere not built, needs either UG or ALU for the log mesh." << std::endl;
+#warning Evaporation Atmosphere not built, needs either UG or dune-ALUGrid for the log mesh.
+    std::cerr << "Evaporation Atmosphere not built, needs either UG or dune-ALUGrid for the log mesh." << std::endl;
     return 77;
 #else
     typedef TTAG(EvaporationAtmosphereProblem) ProblemTypeTag;
diff --git a/test/multidomain/2cnistokes2p2cni/test_2cnistokes2p2cni.cc b/test/multidomain/2cnistokes2p2cni/test_2cnistokes2p2cni.cc
index c6e1c45e12216d411b935e36e9e66e024ee75d43..be4058b07bf7f95e5cf80f99f849607b28655b8f 100644
--- a/test/multidomain/2cnistokes2p2cni/test_2cnistokes2p2cni.cc
+++ b/test/multidomain/2cnistokes2p2cni/test_2cnistokes2p2cni.cc
@@ -281,12 +281,10 @@ int main(int argc, char** argv)
 
 #else
 
-#warning You need to have dune-multidomain installed to run this test
-
-int main()
+int main(int argc, char** argv)
 {
+#warning You need to have dune-multidomain installed to run this test
     std::cerr << "You need to have dune-multidomain installed to run this test\n";
     return 77;
 }
-
 #endif
diff --git a/test/multidomain/2cnizeroeq2p2cni/test_2cnizeroeq2p2cni.cc b/test/multidomain/2cnizeroeq2p2cni/test_2cnizeroeq2p2cni.cc
index e361fbe07de27421f8392c7a0172c6848aef3ef7..fff7ec1fdba98485969194febad8a12e3e04489e 100644
--- a/test/multidomain/2cnizeroeq2p2cni/test_2cnizeroeq2p2cni.cc
+++ b/test/multidomain/2cnizeroeq2p2cni/test_2cnizeroeq2p2cni.cc
@@ -351,13 +351,10 @@ int main(int argc, char** argv)
 }
 
 #else
-
-#warning You need to have dune-multidomain installed to run this test
-
 int main()
 {
+#warning You need to have dune-multidomain installed to run this test
     std::cerr << "You need to have dune-multidomain installed to run this test\n";
     return 77;
 }
-
 #endif
diff --git a/test/multidomain/2cstokes2p2c/test_2cstokes2p2c.cc b/test/multidomain/2cstokes2p2c/test_2cstokes2p2c.cc
index b7da3f07ed876cb7d7f4425453256b507d1c0f9d..bd8ec6d7669075414337144dbcaf51eac102cb42 100644
--- a/test/multidomain/2cstokes2p2c/test_2cstokes2p2c.cc
+++ b/test/multidomain/2cstokes2p2c/test_2cstokes2p2c.cc
@@ -275,13 +275,10 @@ int main(int argc, char** argv)
 }
 
 #else
-
-#warning You need to have dune-multidomain installed to run this test
-
-int main()
+int main(int argc, char** argv)
 {
+#warning You need to have dune-multidomain installed to run this test
     std::cerr << "You need to have dune-multidomain installed to run this test\n";
     return 77;
 }
-
 #endif
diff --git a/test/multidomain/2czeroeq2p2c/test_2czeroeq2p2c.cc b/test/multidomain/2czeroeq2p2c/test_2czeroeq2p2c.cc
index fbd277e3c4e1c506f5fa812935acb1a3e48c47da..bf443042f54dcc7d4043eb33498a43dc51613bc4 100644
--- a/test/multidomain/2czeroeq2p2c/test_2czeroeq2p2c.cc
+++ b/test/multidomain/2czeroeq2p2c/test_2czeroeq2p2c.cc
@@ -339,13 +339,10 @@ int main(int argc, char** argv)
 }
 
 #else
-
-#warning You need to have dune-multidomain installed to run this test
-
-int main()
+int main(int argc, char** argv)
 {
+#warning You need to have dune-multidomain installed to run this test
     std::cerr << "You need to have dune-multidomain installed to run this test\n";
     return 77;
 }
-
 #endif
diff --git a/test/freeflow/navierstokes/test_navierstokes.cc b/test/freeflow/navierstokes/test_navierstokes.cc
index 7bb7e20163c56c79ca75a3794a705ee70edb94ce..c77ff0ae6da81b326d3b734cc8d7b2aba2a7a33b 100644
--- a/test/freeflow/navierstokes/test_navierstokes.cc
+++ b/test/freeflow/navierstokes/test_navierstokes.cc
@@ -55,8 +55,8 @@ int main(int argc, char** argv)
     typedef TTAG(NavierStokesTestProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-#warning "You need to have SuperLU and ALUGrid or UG to run this test."
-    std::cout << "You need to have SuperLU and ALUGrid or UG to run this test." << std::endl;
+#warning "You need to have SuperLU and dune-ALUGrid or UG to run this test."
+    std::cerr << "You need to have SuperLU and dune-ALUGrid or UG to run this test." << std::endl;
     return 77;
 #endif
 }
diff --git a/test/implicit/mpnc/test_boxmpncthermalnonequil.cc b/test/implicit/mpnc/test_boxmpncthermalnonequil.cc
index a577a4ac163ff4986ff59e2fe2d29a33bda172d4..505bf72677a4749b4317b6d9dd382ff575ff4ee3 100644
--- a/test/implicit/mpnc/test_boxmpncthermalnonequil.cc
+++ b/test/implicit/mpnc/test_boxmpncthermalnonequil.cc
@@ -62,7 +62,8 @@ int main(int argc, char** argv)
   typedef TTAG(CombustionProblemOneComponent) ProblemTypeTag;
   return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-#warning CombustionProblemOneComponent skipped, needs Super LU!
+#warning CombustionProblemOneComponent skipped, needs SuperLU!
+  std::cerr << "CombustionProblemOneComponent skipped, needs SuperLU!" << std::endl;
   return 77;
 #endif
 